pub enum CheckedOrUncheckedCustomParameters {
UncheckedCustomParameters(Arc<UncheckedCustomParameters>),
CustomParameters(Arc<CustomParameters>),
}Expand description
Need to be able to handle unchecked custom parameters for parsing
since there’s no config file for parsing a file system, or more to
the point, when the config changes, the file system must still be
readable, thus the representation must remain independent of the
config. But allow to represent both. Do this at runtime for
~simplicity. (Maybe this should be moved to where the contained
types are defined, which maybe shouldn’t all be in key.rs.)
Variants
UncheckedCustomParameters(Arc<UncheckedCustomParameters>)
CustomParameters(Arc<CustomParameters>)
Implementations
Sourceimpl CheckedOrUncheckedCustomParameters
impl CheckedOrUncheckedCustomParameters
pub fn extend_path(&self, path: PathBuf) -> PathBuf
pub fn get(&self, key: &AllowedEnvVar<AllowableCustomEnvVar>) -> Option<&str>