Struct ParametersDir

pub struct ParametersDir { /* private fields */ }
The dir representing all of a key except for the commit id (i.e. custom parameters and target name–note that this is not the same info as RunParameters contains!).

Note that it contains env vars that may not be checked against the config. They are still guaranteed to follow the general requirements for env var names (as per AllowedEnvVar<AllowableCustomEnvVar>::from_str). Similarly, target_name may not be checked against anything (other than being a directory name).

Implementations

Source

impl ParametersDir

pub fn base_path(&self) -> &Arc<Path>

pub fn target_name(&self) -> &ProperDirname

pub fn custom_parameters(&self) -> &CheckedOrUncheckedCustomParameters

pub fn from_job_template( base_path: Arc<Path>, job_template: &JobTemplate, ) -> Self