pub struct RunDir { /* private fields */ }Expand description
Dir with the results for an individual benchmarking run. I.e. one
level below a KeyDir.
Implementations
Sourceimpl RunDir
impl RunDir
Sourcepub fn post_process_single(
&self,
evobench_log_path: Option<&Path>,
evaluating_benchmark_file_succeeded: impl FnOnce() -> Result<()>,
target_name: &ProperDirname,
standard_log_path: &Path,
run_config: &RunConfig,
no_stats: bool,
) -> Result<()>
pub fn post_process_single( &self, evobench_log_path: Option<&Path>, evaluating_benchmark_file_succeeded: impl FnOnce() -> Result<()>, target_name: &ProperDirname, standard_log_path: &Path, run_config: &RunConfig, no_stats: bool, ) -> Result<()>
Produce the “single” extract files, as well as other
configured derivatives. After the standard “single” extracts
succeeded, evaluating_benchmark_file_succeeded is run; it
should remove the file at evobench_log_path if this is the
initial run and evobench_log_path pointed to e.g. a
tmpfs. Pass a no-op if calling later on. If
evobench_log_path is None, then the standard location is
used. If no_summary_stats is true, skips Excel and
flamegraph generation for the evobench.log data (other
post-processing is still done, i.e. configured extractions)
Sourceimpl RunDir
impl RunDir
pub fn parent(&self) -> &Arc<KeyDir>
pub fn timestamp(&self) -> &DateTimeWithOffset
Sourcepub fn evobench_log_path(&self) -> PathBuf
pub fn evobench_log_path(&self) -> PathBuf
The path to the compressed evobench.log file
Sourcepub fn evobench_log_uncompressed_path(&self) -> PathBuf
pub fn evobench_log_uncompressed_path(&self) -> PathBuf
The same path as io_utils::zstd_file::decompressed_file_mmap
generates (the call to the aforementioned function happens in
a context outside the runner, hence can’t use this function
here)
Sourcepub fn bench_output_log_path(&self) -> PathBuf
pub fn bench_output_log_path(&self) -> PathBuf
The optional output location that target projects can use,
passed to it via the BENCH_OUTPUT_LOG env variable then
compressed/moved to this location.
Sourcepub fn standard_log_path(&self) -> PathBuf
pub fn standard_log_path(&self) -> PathBuf
The path to the compressed stdout/stderr output from the target application while running this benchmark.
Sourcepub fn append(&self, file_name: &ProperFilename) -> PathBuf
pub fn append(&self, file_name: &ProperFilename) -> PathBuf
Files below a RunDir are normal files (no special type, at least for now)
Sourcepub fn append_str(&self, file_name: &str) -> Result<PathBuf>
pub fn append_str(&self, file_name: &str) -> Result<PathBuf>
Same as append but returns an error if file_name cannot be a
ProperFilename. Only for files (subdirs would be via an
append_subdir_str method, but RunDirs have no subdirs,
currently.)